=======
History
=======

0.2.3 (2020-14-02)
------------------

* Fixed examples
* Bug fix for including csv data in pypi distribution

0.2.2 (2020-09-02)
------------------

* More badges in readme
* Dropped support for python 3.5

0.2.1 (2020-09-02)
------------------

* Switched to object oriented design
* Now supports range of statsmodels estimators!
* Example showing how to save plots to file in docs
* Example showing where estimation results are stored in docs
* Docs example of very large number of specifications

0.1.1 (2020-08-01)
------------------

* Multiple independent, dependent, and control variables implemented as lists. Mutually exclusive control variables implemented. Expansions of categorical variables into mutually exclusive fixed effects implemented.

0.1.0 (2020-07-27)
------------------

* First release on PyPI.
